@@ -5,11 +5,19 @@ import string
 import pyphen
 import pymorphy2
 from nltk import word_tokenize, pos_tag
+import nltk
 import collections
 from linguaf import SUPPORTED_LANGS, __load_json, __check_bool_param, __check_documents_param, __check_lang_param, \
     __check_text_param, __check_words_param
 
 
+try:
+    nltk.data.find('tokenizers/punkt')
+    nltk.data.find('taggers/averaged_perceptron_tagger')
+except:
+    nltk.download('punkt')
+    nltk.download('averaged_perceptron_tagger')
+
 PUNCTUATION = r"""!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~—«»"""
 STOPWORDS = dict()
 
@@ -346,7 +354,7 @@ def get_lexical_items(documents: list, remove_stopwords: bool = False, lang: str
     return lex_items
 
 
-def words_per_sentence(documents: list, lang: str = 'en', remove_stopwords: bool = False) -> list:
+def avg_words_per_sentence(documents: list, lang: str = 'en', remove_stopwords: bool = False) -> list:
     """Calculate average number of words in a sentence based on a list of documents.
 
     Keyword arguments:
